@@ -2,6 +2,7 @@
  * 
  * Copyright (c) 2012 Daniel Nicoletti <dantti12@gmail.com>
  * Copyright (c) 2012 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (c) 2016 Harald Sitter <sitter@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -455,7 +456,9 @@ std::string AptCacheFile::getLongDescriptionParsed(const pkgCache::VerIterator &
 
 bool AptCacheFile::tryToInstall(pkgProblemResolver &Fix,
                                 const pkgCache::VerIterator &ver,
-                                bool BrokenFix)
+                                bool BrokenFix,
+                                bool autoInst,
+                                bool preserveAuto)
 {
     pkgCache::PkgIterator Pkg = ver.ParentPkg();
 
@@ -471,12 +474,20 @@ bool AptCacheFile::tryToInstall(pkgProblemResolver &Fix,
         return false;
     }
 
+    // On updates we want to always preserve the autoflag as updates are usually
+    // non-indicative of whether or not the user explicitly wants this package to be
+    // installed or simply wants it to be updated.
+    const bool fromUser = preserveAuto ? !(State.Flags & pkgCache::Flag::Auto) : true;
+    // FIXME: this is ignoring the return value. OTOH the return value means little to us
+    //   since we run markinstall twice, once without autoinst and once with.
+    //   We probably should change the return value behavior and have the callee decide whether to
+    //   error out or call us again with autoinst. This however is further complicated by us
+    //   having protected, so we'd have to lift protection before this?
+    GetDepCache()->MarkInstall(Pkg, autoInst, 0, fromUser);
+    // Protect against further resolver changes.
     Fix.Clear(Pkg);
     Fix.Protect(Pkg);
 
-    // Install it
-    GetDepCache()->MarkInstall(Pkg, false);
-
     return true;
 }
 
