@@ -26,6 +26,7 @@
 #include <glib/gstdio.h>
 
 #include <fstream>
+#include <regex>
 
 PkGroupEnum get_enum_group(string group)
 {
@@ -371,16 +372,29 @@ string utilBuildPackageOriginId(pkgCache::VerFileIterator vf)
     if (vf.File().Component() == NULL)
         return string("invalid");
 
-    // Origin, e.g. "Debian" or "Google Inc."
+    // https://wiki.debian.org/DebianRepository/Format
+    // Optional field indicating the origin of the repository, a single line of free form text.
+    // e.g. "Debian" or "Google Inc."
     auto origin = string(vf.File().Origin());
-    // The suite, e.g. "jessie" or "sid"
+    // The Suite field may describe the suite. A suite is a single word.
+    // e.g. "jessie" or "sid"
     auto suite = string(vf.File().Archive());
-    // The component, e.g. "main" or "non-free"
+    // An area within the repository. May be prefixed by parts of the path
+    // following the directory beneath dists.
+    // e.g. "main" or "non-free"
+    // NOTE: this may need the slash stripped, currently having a slash doesn't
+    //    seem a problem though. we'll allow them until otherwise indicated
     auto component = string(vf.File().Component());
 
-    // sanitize origin string
+    // Origin is defined as 'a single line of free form text'.
+    // Sanitize it!
+    // All space characters, control characters and punctuation get replaced
+    // with underscore.
+    // In particular the punctuations ',' and ';' may be used as list separators
+    // so we must not have them appear in our package_ids as that would break
+    // any number of higher level features.
     std::transform(origin.begin(), origin.end(), origin.begin(), ::tolower);
-    std::replace(origin.begin(), origin.end(), ' ', '_');
+    origin = std::regex_replace(origin, std::regex("[[:space:][:cntrl:][:punct:]]+"), "_");
 
     string res = origin + "-" + suite + "-" + component;
     return res;
