@@ -108,7 +108,7 @@ G_DEFINE_TYPE (PkTask, pk_task, PK_TYPE_CLIENT)
 
 static void pk_task_ready_cb (GObject *source_object, GAsyncResult *res, PkTaskState *state);
 
-/**
+/*
  * pk_task_generate_request_id:
  **/
 static guint
@@ -118,7 +118,7 @@ pk_task_generate_request_id (void)
 	return ++id;
 }
 
-/**
+/*
  * pk_task_find_by_request:
  **/
 static PkTaskState *
@@ -140,7 +140,7 @@ pk_task_find_by_request (PkTask *task, guint request)
 	return NULL;
 }
 
-/**
+/*
  * pk_task_generic_state_finish:
  **/
 static void
@@ -184,7 +184,7 @@ pk_task_generic_state_finish (PkTaskState *state, const GError *error)
 	g_slice_free (PkTaskState, state);
 }
 
-/**
+/*
  * pk_task_do_async_action:
  **/
 static void
@@ -318,7 +318,7 @@ pk_task_do_async_action (PkTaskState *state)
 	}
 }
 
-/**
+/*
  * pk_task_package_filter_cb:
  **/
 static gboolean
@@ -337,7 +337,7 @@ pk_task_package_filter_cb (PkPackage *package, gpointer user_data)
 
 static void pk_task_do_async_simulate_action (PkTaskState *state);
 
-/**
+/*
  * pk_task_simulate_ready_cb:
  **/
 static void
@@ -371,7 +371,7 @@ pk_task_simulate_ready_cb (GObject *source_object, GAsyncResult *res, PkTaskStat
 	}
 
 	/* we own a copy now */
-	state->results = g_object_ref (G_OBJECT(results));
+	state->results = g_object_ref (results);
 
 	/* get exit code */
 	state->exit_enum = pk_results_get_exit_code (state->results);
@@ -421,7 +421,7 @@ pk_task_simulate_ready_cb (GObject *source_object, GAsyncResult *res, PkTaskStat
 	klass->simulate_question (state->task, state->request, state->results);
 }
 
-/**
+/*
  * pk_task_do_async_simulate_action:
  **/
 static void
@@ -507,7 +507,7 @@ pk_task_do_async_simulate_action (PkTaskState *state)
 	}
 }
 
-/**
+/*
  * pk_task_install_signatures_ready_cb:
  **/
 static void
@@ -531,7 +531,7 @@ pk_task_install_signatures_ready_cb (GObject *source_object, GAsyncResult *res,
 	}
 
 	/* we own a copy now */
-	state->results = g_object_ref (G_OBJECT(results));
+	state->results = g_object_ref (results);
 
 	/* get exit code */
 	state->exit_enum = pk_results_get_exit_code (state->results);
@@ -552,7 +552,7 @@ pk_task_install_signatures_ready_cb (GObject *source_object, GAsyncResult *res,
 	pk_task_do_async_action (state);
 }
 
-/**
+/*
  * pk_task_install_signatures:
  **/
 static void
@@ -599,7 +599,7 @@ pk_task_install_signatures (PkTaskState *state)
 					   (GAsyncReadyCallback) pk_task_install_signatures_ready_cb, state);
 }
 
-/**
+/*
  * pk_task_accept_eulas_ready_cb:
  **/
 static void
@@ -623,7 +623,7 @@ pk_task_accept_eulas_ready_cb (GObject *source_object, GAsyncResult *res, PkTask
 	}
 
 	/* we own a copy now */
-	state->results = g_object_ref (G_OBJECT(results));
+	state->results = g_object_ref (results);
 
 	/* get exit code */
 	state->exit_enum = pk_results_get_exit_code (state->results);
@@ -644,7 +644,7 @@ pk_task_accept_eulas_ready_cb (GObject *source_object, GAsyncResult *res, PkTask
 	pk_task_do_async_action (state);
 }
 
-/**
+/*
  * pk_task_accept_eulas:
  **/
 static void
@@ -652,7 +652,7 @@ pk_task_accept_eulas (PkTaskState *state)
 {
 	PkEulaRequired *item;
 	g_autoptr(GError) error = NULL;
-	g_autofree gchar *eula_id = NULL;
+	const gchar *eula_id;
 	g_autoptr(GPtrArray) array = NULL;
 
 	/* get results */
@@ -677,9 +677,7 @@ pk_task_accept_eulas (PkTaskState *state)
 
 	/* get first item of data */
 	item = g_ptr_array_index (array, 0);
-	g_object_get (item,
-		      "eula-id", &eula_id,
-		      NULL);
+	eula_id = pk_eula_required_get_eula_id (item);
 
 	/* do new async method */
 	pk_client_accept_eula_async (PK_CLIENT(state->task), eula_id,
@@ -687,7 +685,7 @@ pk_task_accept_eulas (PkTaskState *state)
 				     (GAsyncReadyCallback) pk_task_accept_eulas_ready_cb, state);
 }
 
-/**
+/*
  * pk_task_repair_ready_cb:
  **/
 static void
@@ -711,7 +709,7 @@ pk_task_repair_ready_cb (GObject *source_object, GAsyncResult *res, PkTaskState
 	}
 
 	/* we own a copy now */
-	state->results = g_object_ref (G_OBJECT(results));
+	state->results = g_object_ref (results);
 
 	/* get exit code */
 	state->exit_enum = pk_results_get_exit_code (state->results);
@@ -733,7 +731,7 @@ pk_task_repair_ready_cb (GObject *source_object, GAsyncResult *res, PkTaskState
 	pk_task_do_async_action (state);
 }
 
-/**
+/*
  * pk_task_user_accepted_idle_cb:
  **/
 static gboolean
@@ -773,6 +771,12 @@ pk_task_user_accepted_idle_cb (PkTaskState *state)
 
 /**
  * pk_task_user_accepted:
+ * @task: a valid #PkTask instance
+ * @request: request ID for EULA.
+ *
+ * Mark a EULA as accepted by the user.
+ *
+ * Return value: %TRUE if @request is valid.
  *
  * Since: 0.5.2
  **/
@@ -796,7 +800,7 @@ pk_task_user_accepted (PkTask *task, guint request)
 	return TRUE;
 }
 
-/**
+/*
  * pk_task_user_declined_idle_cb:
  **/
 static gboolean
@@ -824,6 +828,12 @@ pk_task_user_declined_idle_cb (PkTaskState *state)
 
 /**
  * pk_task_user_declined:
+ * @task: a valid #PkTask instance
+ * @request: request ID for EULA.
+ *
+ * Mark a EULA as declined by the user.
+ *
+ * Return value: %TRUE if @request is valid.
  *
  * Since: 0.5.2
  **/
@@ -847,7 +857,7 @@ pk_task_user_declined (PkTask *task, guint request)
 	return TRUE;
 }
 
-/**
+/*
  * pk_task_retry_cancelled_transaction_cb:
  **/
 static gboolean
@@ -859,7 +869,7 @@ pk_task_retry_cancelled_transaction_cb (gpointer user_data)
 	return FALSE;
 }
 
-/**
+/*
  * pk_task_ready_cb:
  **/
 static void
@@ -885,7 +895,7 @@ pk_task_ready_cb (GObject *source_object, GAsyncResult *res, PkTaskState *state)
 	}
 
 	/* we own a copy now */
-	state->results = g_object_ref (G_OBJECT(results));
+	state->results = g_object_ref (results);
 
 	/* get exit code */
 	state->exit_enum = pk_results_get_exit_code (state->results);
@@ -1221,7 +1231,7 @@ pk_task_upgrade_system_async (PkTask *task,
  * @user_data: the data to pass to @callback_ready
  *
  * Remove a package (optionally with dependancies) from the system.
- * If %allow_deps is set to %FALSE, and other packages would have to be removed,
+ * If @allow_deps is set to %FALSE, and other packages would have to be removed,
  * then the transaction would fail.
  *
  * Since: 0.5.2
@@ -2043,7 +2053,7 @@ pk_task_get_files_async (PkTask *task, gchar **package_ids, GCancellable *cancel
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope notified): the function to run when the progress changes
  * @progress_user_data: data to pass to @progress_callback
- * @callback_ready (scope async): the function to run on completion
+ * @callback_ready: (scope async): the function to run on completion
  * @user_data: the data to pass to @callback
  *
  * Get the categories available.
@@ -2185,7 +2195,7 @@ pk_task_get_repo_list_async (PkTask *task, PkBitfield filters, GCancellable *can
 /**
  * pk_task_repo_enable_async:
  * @task: a valid #PkTask instance
- * @repo_id: The software source ID
+ * @repo_id: The software repository ID
  * @enabled: %TRUE or %FALSE
  * @cancellable: a #GCancellable or %NULL
  * @progress_callback: (scope notified): the function to run when the progress changes
@@ -2373,7 +2383,7 @@ pk_task_set_only_download (PkTask *task, gboolean only_download)
  *
  * Gets if we are just preparing the transaction for later.
  *
- * Return value: %TRUE if we are simulating
+ * Return value: %TRUE if only downloading
  *
  * Since: 0.8.1
  **/
@@ -2477,7 +2487,7 @@ pk_task_set_allow_reinstall (PkTask *task, gboolean allow_reinstall)
  *
  * Gets if we allow packages to be reinstalled.
  *
- * Return value: %TRUE if package downgrades are allowed
+ * Return value: %TRUE if package reinstallation is allowed
  *
  * Since: 1.0.2
  **/
@@ -2488,7 +2498,7 @@ pk_task_get_allow_reinstall (PkTask *task)
 	return task->priv->allow_reinstall;
 }
 
-/**
+/*
  * pk_task_get_property:
  **/
 static void
@@ -2519,7 +2529,7 @@ pk_task_get_property (GObject *object, guint prop_id, GValue *value, GParamSpec
 	}
 }
 
-/**
+/*
  * pk_task_set_property:
  **/
 static void
@@ -2550,7 +2560,7 @@ pk_task_set_property (GObject *object, guint prop_id, const GValue *value, GPara
 	}
 }
 
-/**
+/*
  * pk_task_class_init:
  **/
 static void
@@ -2565,6 +2575,8 @@ pk_task_class_init (PkTaskClass *klass)
 	/**
 	 * PkTask:simulate:
 	 *
+         * %TRUE if we are simulating.
+         *
 	 * Since: 0.5.2
 	 */
 	pspec = g_param_spec_boolean ("simulate", NULL, NULL,
@@ -2575,6 +2587,8 @@ pk_task_class_init (PkTaskClass *klass)
 	/**
 	 * PkTask:only-download:
 	 *
+         * %TRUE if we are just preparing the transaction for later.
+         *
 	 * Since: 0.8.1
 	 */
 	pspec = g_param_spec_boolean ("only-download", NULL, NULL,
@@ -2585,6 +2599,8 @@ pk_task_class_init (PkTaskClass *klass)
 	/**
 	 * PkTask:only-trusted:
 	 *
+         * %TRUE if only authenticated packages should be allowed in the transaction.
+         *
 	 * Since: 0.9.5
 	 */
 	pspec = g_param_spec_boolean ("only-trusted", NULL, NULL,
@@ -2595,6 +2611,8 @@ pk_task_class_init (PkTaskClass *klass)
 	/**
 	 * PkTask:allow-reinstall:
 	 *
+         * %TRUE if package reinstallation shall be allowed during transaction.
+         *
 	 * Since: 1.0.2
 	 */
 	pspec = g_param_spec_boolean ("allow-reinstall", NULL, NULL,
@@ -2605,6 +2623,8 @@ pk_task_class_init (PkTaskClass *klass)
 	/**
 	 * PkTask:allow-downgrade:
 	 *
+         * %TRUE if package downgrades are allowed.
+         *
 	 * Since: 1.0.2
 	 */
 	pspec = g_param_spec_boolean ("allow-downgrade", NULL, NULL,
@@ -2615,7 +2635,7 @@ pk_task_class_init (PkTaskClass *klass)
 	g_type_class_add_private (klass, sizeof (PkTaskPrivate));
 }
 
-/**
+/*
  * pk_task_init:
  **/
 static void
@@ -2628,7 +2648,7 @@ pk_task_init (PkTask *task)
 	task->priv->allow_downgrade = FALSE;
 }
 
-/**
+/*
  * pk_task_finalize:
  **/
 static void
@@ -2642,7 +2662,7 @@ pk_task_finalize (GObject *object)
 /**
  * pk_task_new:
  *
- * Return value: a new PkTask object.
+ * Return value: a new #PkTask object.
  *
  * Since: 0.5.2
  **/
