@@ -947,6 +947,29 @@ pk_backend_convert_uri (const gchar *proxy)
 	return g_string_free (string, FALSE);
 }
 
+/**
+ * pk_backend_convert_uri_socks:
+ *
+ * Convert a proxy string to a SOCKS URI.
+ **/
+gchar *
+pk_backend_convert_uri_socks (const gchar *proxy)
+{
+	GString *string;
+	string = g_string_new (proxy);
+
+	/* if we didn't specify a prefix, add a default one */
+	if (!g_str_has_prefix (proxy, "socks://")) {
+		g_string_prepend (string, "socks://");
+	}
+
+	/* if we didn't specify a trailing slash, add one */
+	if (!g_str_has_suffix (proxy, "/"))
+		g_string_append_c (string, '/');
+
+	return g_string_free (string, FALSE);
+}
+
 /**
  * pk_backend_get_name:
  **/
