@@ -178,32 +178,33 @@ pk_dbus_get_cmdline (PkDbus *dbus, const gchar *sender)
 }
 
 #ifdef HAVE_SYSTEMD
+static gchar *
+pk_dbus_make_logind_session_id (const gchar *session)
+{
+	g_assert (session != NULL);
+	return g_strdup_printf ("/org/freedesktop/logind/session-%s", session);
+}
+
 /**
  * pk_dbus_get_session_systemd:
  **/
 static gchar *
 pk_dbus_get_session_systemd (guint pid)
 {
-	gchar *session = NULL;
-	gchar *session_tmp = NULL;
-	gint rc;
+	g_autofree gchar *session_id = NULL;
+	uid_t uid;
 
-	rc = sd_pid_get_session (pid, &session_tmp);
-	if (rc < 0) {
-		g_warning ("failed to get session, errno %i", rc);
-		goto out;
-	}
-	if (session_tmp == NULL) {
-		g_warning ("no session for %i", pid);
-		goto out;
-	}
+	/* do process -> pid -> same session */
+	if (sd_pid_get_session (pid, &session_id) >= 0)
+		return pk_dbus_make_logind_session_id (session_id);
 
-	/* convert to a GLib allocated string */
-	session = g_strdup_printf ("/org/freedesktop/logind/session-%s",
-				   session_tmp);
-out:
-	free (session_tmp);
-	return session;
+	/* do process -> uid -> graphical session */
+	if (sd_pid_get_owner_uid (pid, &uid) < 0)
+		return NULL;
+	if (sd_uid_get_display (uid, &session_id) >= 0)
+		return pk_dbus_make_logind_session_id (session_id);
+
+	return NULL;
 }
 #endif
 
@@ -252,6 +253,8 @@ pk_dbus_get_session (PkDbus *dbus, const gchar *sender)
 	/* get session from systemd or ConsoleKit */
 #ifdef HAVE_SYSTEMD
 	session = pk_dbus_get_session_systemd (pid);
+	if (session == NULL)
+		g_warning ("failed to get session for pid %u", pid);
 #else
 	/* get session from ConsoleKit */
 	value = g_dbus_proxy_call_sync (dbus->priv->proxy_session,
